@@ -28,12 +28,18 @@ class CalAccessCommand(BaseCommand):
 
     def handle(self, *args, **options):
         """
-        Sets options common to all commands.
+        The generic handler function.
 
         Any command subclassing this object should implement its own
         handle method, as is standard in Django, and run this method
         via a super call to inherit its functionality.
         """
+        self.set_global_options(options)
+
+    def set_global_options(self, options):
+        """
+        Set options to all commands.
+        """
         # Set global options
         self.verbosity = options.get("verbosity")
         self.no_color = options.get("no_color")
@@ -75,7 +81,7 @@ class CalAccessCommand(BaseCommand):
         """
         Returns a dict with metadata about the current CAL-ACCESS snapshot.
         """
-        response = requests.head(self.url)
+        response = requests.head(self.url, verify=False)
         logger.debug(
             'Response status {0.status_code} ({0.reason}) from HEAD request.'.format(response)
         )
